@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: DirHandle.pm,v 1.7 2001/06/12 17:08:48 rbrown Exp $
+# $Id: DirHandle.pm,v 1.8 2001/10/10 10:05:37 rich Exp $
 
 =pod
 
@@ -403,36 +403,6 @@ sub open
       }
   }
 
-sub can_write
-  {
-    return 1;
-  }
-
-sub can_delete
-  {
-    return 1;
-  }
-
-sub can_enter
-  {
-    return 1;
-  }
-
-sub can_list
-  {
-    return 1;
-  }
-
-sub can_rename
-  {
-    return 1;
-  }
-
-sub can_mkdir
-  {
-    return 1;
-  }
-
 1 # So that the require or use succeeds.
 
 __END__
